%define subver          %{nil}
%define major		12
%define libname		%mklibname cryptsetup %{major}
%define dlibname	%mklibname cryptsetup -d

%define url_ver		%(echo %{version}|cut -d. -f1,2)

%bcond_with compatible

Name:		cryptsetup
Version:	2.3.7
Release:	%mkrel 1
Summary:	Utility for setting up encrypted filesystems
License:	GPLv2+ and LGPLv2+
Group:		System/Base
URL:		https://gitlab.com/cryptsetup/cryptsetup
Source0:	https://www.kernel.org/pub/linux/utils/cryptsetup/v%{url_ver}/cryptsetup-%{version}.tar.xz
Source1:	https://www.kernel.org/pub/linux/utils/cryptsetup/v%{url_ver}/cryptsetup-%{version}.tar.sign
BuildRequires:	libgcrypt-devel >= 1.1.42
BuildRequires:	libgpg-error-devel
BuildRequires:	pkgconfig(blkid)
BuildRequires:	pkgconfig(devmapper)
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(systemd)
BuildRequires:	pkgconfig(libargon2)
BuildRequires:	pkgconfig(pwquality)
Obsoletes:	cryptsetup-luks < 1.0.5
Provides:	cryptsetup-luks = %{version}-%{release}
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	systemd >= %{systemd_required_version}

%description
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

LUKS for dm-crypt is implemented in cryptsetup. cryptsetup-luks is
a complete replacement for the original cryptsetup. It provides all the
functionally of the original version plus all the LUKS features, which are
accessible by the luks* commands.

%package -n	%{libname}
Summary:	Library for setting up encrypted filesystems
Group:		System/Libraries

%description -n %{libname}
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

This package contains the shared libraries required for running
programs which use cryptsetup-luks.


%package -n	%{dlibname}
Summary:	Development library for setting up encrypted filesystems
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	cryptsetup-devel
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%mklibname -d cryptsetup 0

%description -n %{dlibname}
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

This package contains the header files and development libraries
for building programs which use cryptsetup-luks.

%prep
%autosetup -n cryptsetup-%{version} -p 1

iconv -f ISO-8859-1 -t UTF8 ChangeLog -o ChangeLog.new
mv -f ChangeLog.new ChangeLog

%build
%configure --enable-pwquality --enable-libargon2 --disable-selinux
%if %{with compatible}
	--with-plain-mode=cbc-plain --with-luks1-keybits=128 \
%endif
# end of configure
%make_build

%install
%make_install
rm -f %{buildroot}%{_libdir}/libcryptsetup.la

%find_lang %{name}

%post
%_tmpfilescreate %{_tmpfilesdir}/%{name}

%files -f %{name}.lang
%doc ChangeLog AUTHORS FAQ INSTALL NEWS README TODO
%{_sbindir}/cryptsetup
%{_sbindir}/veritysetup
%{_sbindir}/cryptsetup-reencrypt
%{_sbindir}/integritysetup
%{_mandir}/man8/cryptsetup.8*
%{_mandir}/man8/veritysetup.8*
%{_mandir}/man8/cryptsetup-reencrypt.8*
%{_mandir}/man8/integritysetup.8*
%{_tmpfilesdir}/%{name}.conf

%files -n %{dlibname}
%{_includedir}/libcryptsetup.h
%{_libdir}/libcryptsetup.so
%{_libdir}/pkgconfig/libcryptsetup.pc

%files -n %{libname}
%{_libdir}/libcryptsetup.so.%{major}{,.*}



%changelog
* Sat Jan 29 2022 mrambo3501 <mrambo3501> 2.3.7-1.mga8
+ Revision: 1770207
- version 2.3.7 fixes CVE-2021-4122 (mga#29884)

* Sun Nov 29 2020 luigiwalser <luigiwalser> 2.3.4-2.mga8
+ Revision: 1650330
- rebuild for json-c

* Fri Sep 04 2020 tv <tv> 2.3.4-1.mga8
+ Revision: 1621654
- Update to cryptsetup 2.3.4.
- Fix for CVE-2020-14382

* Thu May 28 2020 tv <tv> 2.3.3-1.mga8
+ Revision: 1588440
- 2.3.3

* Sat May 02 2020 tv <tv> 2.3.2-1.mga8
+ Revision: 1577897
- link with (faster) libargon2, thus fixing:
  "-configure: WARNING: Argon2 bundled (slow) reference implementation will be used, please consider to use system library with --enable-libargon2"
- link with libpwquality
- use %%autosetup
- drop support for static lib which was never enabled on any Mga release
- fix license
- 2.3.2

* Fri Mar 20 2020 shlomif <shlomif> 2.3.1-2.mga8
+ Revision: 1558268
- New version 2.3.1

* Thu Feb 20 2020 umeabot <umeabot> 2.3.0-2.mga8
+ Revision: 1547335
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 shlomif <shlomif> 2.3.0-1.mga8
+ Revision: 1487883
- New version 2.3.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Dec 07 2019 shlomif <shlomif> 2.2.2-1.mga8
+ Revision: 1465042
- New version 2.2.2

* Tue Aug 20 2019 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1430628
- new version: 2.2.0

* Tue Feb 12 2019 shlomif <shlomif> 2.1.0-1.mga7
+ Revision: 1366065
- Add BRs
- New version 2.1.0

* Sat Dec 22 2018 shlomif <shlomif> 2.0.6-1.mga7
+ Revision: 1344483
- New version 2.0.6

* Thu Nov 22 2018 shlomif <shlomif> 2.0.5-1.mga7
+ Revision: 1333250
- New version 2.0.5

* Sun Sep 23 2018 umeabot <umeabot> 2.0.4-2.mga7
+ Revision: 1297336
- Mageia 7 Mass Rebuild

* Sun Aug 12 2018 tmb <tmb> 2.0.4-1.mga7
+ Revision: 1251128
- BR: pkgconfig(blkid)
- update to 2.0.4
- rebuild for new libjson major

* Wed May 16 2018 shlomif <shlomif> 2.0.3-1.mga7
+ Revision: 1229881
- New version 2.0.3

* Thu Mar 22 2018 kekepower <kekepower> 2.0.2-1.mga7
+ Revision: 1211331
- Update to version 2.0.2

* Wed Mar 14 2018 kekepower <kekepower> 2.0.0-2.mga7
+ Revision: 1209535
- Fixed installation of tmpfiles

* Wed Mar 14 2018 kekepower <kekepower> 2.0.0-1.mga7
+ Revision: 1209403
- Added BR for systemd
- Added BR for json-devel
- Update to version 2.0.0
- Fixed files list
- Added %%post action for tmpfilescreate

* Mon May 01 2017 luigiwalser <luigiwalser> 1.7.5-1.mga6
+ Revision: 1098163
- 1.7.5

* Sat Mar 18 2017 luigiwalser <luigiwalser> 1.7.4-1.mga6
+ Revision: 1093552
- 1.7.4

* Fri Nov 11 2016 luigiwalser <luigiwalser> 1.7.3-1.mga6
+ Revision: 1066477
- 1.7.3

* Wed Aug 10 2016 luigiwalser <luigiwalser> 1.7.2-1.mga6
+ Revision: 1045264
- 1.7.2
+ shlomif <shlomif>
- .spec cleanups - new macros, trailing space, typos.

* Mon May 09 2016 luigiwalser <luigiwalser> 1.7.1-1.mga6
+ Revision: 1011340
- 1.7.1

* Thu Dec 31 2015 luigiwalser <luigiwalser> 1.7.0-1.mga6
+ Revision: 917395
- 1.7.0

* Sun Sep 13 2015 ycantin <ycantin> 1.6.8-1.mga6
+ Revision: 878914
- new version  1.6.8

* Thu Sep 10 2015 fwang <fwang> 1.6.7-3.mga6
+ Revision: 875416
- rebuild for new libgcrypt

* Fri Aug 21 2015 tmb <tmb> 1.6.7-2.mga6
+ Revision: 867559
- rebuild for new gcc

* Sat Jul 25 2015 blino <blino> 1.6.7-1.mga6
+ Revision: 857131
- update URL
- 1.6.7

* Wed Oct 15 2014 umeabot <umeabot> 1.6.6-4.mga5
+ Revision: 741135
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.6.6-3.mga5
+ Revision: 693701
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.6.6-2.mga5
+ Revision: 678598
- Mageia 5 Mass Rebuild

* Mon Aug 18 2014 luigiwalser <luigiwalser> 1.6.6-1.mga5
+ Revision: 665229
- 1.6.6

* Wed Jul 02 2014 luigiwalser <luigiwalser> 1.6.5-1.mga5
+ Revision: 642313
- 1.6.5

* Sat Mar 01 2014 luigiwalser <luigiwalser> 1.6.4-1.mga5
+ Revision: 598389
- 1.6.4
- update source URLs

* Mon Dec 16 2013 luigiwalser <luigiwalser> 1.6.3-1.mga4
+ Revision: 557950
- 1.6.3

* Sat Oct 19 2013 umeabot <umeabot> 1.6.2-2.mga4
+ Revision: 534386
- Mageia 4 Mass Rebuild

* Wed Sep 11 2013 colin <colin> 1.6.2-1.mga4
+ Revision: 477587
- New version: 1.6.2

* Fri Jan 11 2013 umeabot <umeabot> 1.5.1-2.mga3
+ Revision: 348312
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 28 2012 colin <colin> 1.5.1-1.mga3
+ Revision: 311147
- New version: 1.5.1

* Tue Jul 24 2012 colin <colin> 1.5.0-1.mga3
+ Revision: 273982
- New version: 1.5.0 (needed for systemd >= 187)

* Fri Dec 09 2011 guillomovitch <guillomovitch> 1.4.1-1.mga2
+ Revision: 179493
- new version
- spec cleanup
- drop .la file
+ dlucio <dlucio>
- 1.3.1

* Wed Apr 06 2011 ahmad <ahmad> 1.3.0-1.mga1
+ Revision: 81406
- update to 1.3.0
- fix ChangeLog encoding

* Sat Jan 15 2011 supp <supp> 1.2.0-2.mga1
+ Revision: 19001
- imported package cryptsetup


* Thu Dec 23 2010 Luca Berra <bluca@mandriva.org> 1.2.0-2mdv2011.0
+ Revision: 623997
- add FAQ to docs
- update to 1.2.0
- disable backwards compatible plain-mode cipher
- disable static build, since it requires static libgpg-error

* Wed Jul 28 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.1.3-1mdv2011.0
+ Revision: 562795
- update to new version 1.1.3

* Mon Apr 26 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.1.0-3mdv2010.1
+ Revision: 538984
- arch-independant virtual devel package

  + Funda Wang <fwang@mandriva.org>
    - provides %%name-devel
    - drop unused requires on devel package (corresponding requires already produced by file deps)

* Sun Apr 25 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.1.0-2mdv2010.1
+ Revision: 538749
- ensure devel package requires runtime package

  + Sandro Cazzaniga <kharec@mandriva.org>
    - Fix license
    - Fix mixed of spaces and tabs

* Sun Jan 31 2010 Luca Berra <bluca@mandriva.org> 1.1.0-1mdv2010.1
+ Revision: 498763
- updated to version 1.1.0
- new version 1.1.0-rc2

* Tue Aug 04 2009 Eugeni Dodonov <eugeni@mandriva.com> 1.0.7-2mdv2010.0
+ Revision: 409019
- Updated buildrequires for libuuid.
- rebuild with new libuuid

* Sat Jul 25 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.7-1mdv2010.0
+ Revision: 399843
- Update to new version 1.0.7
- Fix URL and SOURCE location
- Use new --disable-selinux ./configure option to disable selinux
- Remove udevsettle patch: 1.0.7 does not call udevsettle anymore now

* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 1.0.6-4mdv2009.1
+ Revision: 350751
- rebuild

* Mon Sep 01 2008 Olivier Blin <oblin@mandriva.com> 1.0.6-3mdv2009.0
+ Revision: 278110
- use udevadm to settle for udev events (#43350, patch from upstream SVN)
- remove udevsettle patch (merged upstream)

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1.0.6-2mdv2009.0
+ Revision: 264381
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun Jun 01 2008 Funda Wang <fwang@mandriva.org> 1.0.6-1mdv2009.0
+ Revision: 214094
- there is no use remove .so.major, as it is the soname
- New version 1.0.6

* Wed Jan 16 2008 Andreas Hasenack <andreas@mandriva.com> 1.0.5-5mdv2008.1
+ Revision: 153759
- fix race condition with udev by calling udevsettle (patch from ubuntu/debian/suse)

* Fri Jan 11 2008 Thierry Vignaud <tv@mandriva.org> 1.0.5-4mdv2008.1
+ Revision: 149141
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Sep 25 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.5-3mdv2008.0
+ Revision: 92837
- Patch0 (Fedora): add support for LUKS encrypted CD/DVD

* Tue May 08 2007 Andreas Hasenack <andreas@mandriva.com> 1.0.5-2mdv2008.0
+ Revision: 25051
- upstream re-released 1.0.5 with a fix, no need for
  "odd" patch anymore

* Mon May 07 2007 Andreas Hasenack <andreas@mandriva.com> 1.0.5-1mdv2008.0
+ Revision: 24624
- updated to version 1.0.5
- cryptsetup-luks was merged with cryptsetup (upstream rename). There Is Only One now.

* Tue Apr 24 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.3-2mdv2008.0
+ Revision: 17886
- Rebuild for 2008.0
- use new macro

